@@ -360,15 +360,17 @@ class TaurusXYModelChooserTool(Qt.QAction, BaseConfigurableClass):
         events to TaurusXYModelChooserTool
         """
         if source is self.parent():
-            if event.type() == Qt.QEvent.DragEnter:
+            t = event.type()
+            if t == Qt.QEvent.DragEnter:
                 event.acceptProposedAction()
                 return True
-
-            if event.type() == Qt.QEvent.Drop:
+            elif t == Qt.QEvent.Drop:
                 event.acceptProposedAction()
                 return self._dropMimeData(event.mimeData())
+            else:
+                return False
 
-        return self.parent().eventFilter(source, event)
+        return Qt.QAction.eventFilter(self, source, event)
 
     def getModelNames(self):
         """
