@@ -42,6 +42,7 @@ import taurus
 
 
 class TrendCurve(PlotDataItem):
+    """A PlotDataItem for representing 1D trends"""
     def __repr__(self):
         return "<TrendCurve {}>".format(self.name())
 
@@ -81,7 +82,8 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
         colors = kwargs.pop("colors", None)
         if colors is None:
             colors = LoopList(CURVE_COLORS)
-        PlotDataItem.__init__(self, *args, **kwargs)
+        name = kwargs.pop("name", None)
+        PlotDataItem.__init__(self, x=[], y=[], name=name)
         TaurusBaseComponent.__init__(self, "TaurusBaseComponent")
         self._UImodifiable = False
         self._maxBufferSize = 65536  # (=2**16, i.e., 64K events))
@@ -223,7 +225,9 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
                     plotItem = viewWidget.getPlotItem()
                 if plotItem is not None:
                     curve = ensure_unique_curve_name(curve, plotItem)
-                    plotItem.addItem(curve)
+                    _cname = curve.name()
+                    params = {"all trends": _cname}
+                    plotItem.addItem(curve, params=params)
 
     def _updateBuffers(self, evt_value):
         """Update the x and y buffers with the new data. If the new data is
@@ -416,6 +420,10 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
                 c.opts["connect"] = "finite"
 
     def getFullModelNames(self):
+        """
+        Return a tuple of (None, fullmodelname) for API compatibility with
+        :class:`TaurusPlotDataItem`.
+        """
         return (None, self.getFullModelName())
 
     def setBufferSize(self, buffer_size):
@@ -442,8 +450,10 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
                 # resize
                 self._yBuffer.setMaxSize(buffer_size)
         except ValueError:
-            self.info('buffer downsizing  requested.'
-                      + 'Current contents will be discarded')
+            self.info(
+                "buffer downsizing  requested."
+                + "Current contents will be discarded"
+            )
             self.clearBuffer()
 
     def bufferSize(self):
