@@ -182,6 +182,9 @@ class TaurusTrend(PlotWidget, BaseConfigurableClass):
     def __len__(self):
         return len(self._getCurves())
 
+    def __bool__(self):
+        return True
+
     def _getCurves(self):
         """returns a flat list with all items from all trend sets"""
         ret = []
